<?php
/**
 * Holiday Lite Theme Customizer
 *
 * @package Holiday Lite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function holiday_lite_customize_register( $wp_customize ) {
	
function holiday_lite_sanitize_checkbox( $checked ) {
	// Boolean check.
	return ( ( isset( $checked ) && true == $checked ) ? true : false );
}
	
	$wp_customize->get_setting( 'blogname' )->holiday_lite         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->holiday_lite  = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
	    'selector' => 'h1.site-title',
	    'render_callback' => 'holiday_lite_customize_partial_blogname',
	) );

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
	    'selector' => 'p.site-description',
	    'render_callback' => 'holiday_lite_customize_partial_blogdescription',
	) );

	$wp_customize->add_setting('headerbg-color', array(
		'default' => '#ffffff',
		'sanitize_callback'	=> 'sanitize_hex_color',
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'headerbg-color',array(
			'label' => __('Main Header Background Color','holiday-lite'),
			'description'	=> __('Select background color for header.','holiday-lite'),
			'section' => 'colors',
			'settings' => 'headerbg-color'
		))
	);
	
	$wp_customize->add_setting('color_scheme', array(
		'default' => '#f44c28',
		'sanitize_callback'	=> 'sanitize_hex_color',
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'color_scheme',array(
			'label' => __('Color Scheme','holiday-lite'),
			'description'	=> __('Select theme main color from here.','holiday-lite'),
			'section' => 'colors',
			'settings' => 'color_scheme'
		))
	);
	
	$wp_customize->add_setting('color_sub_scheme', array(
		'default' => '#000000',
		'sanitize_callback'	=> 'sanitize_hex_color',
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'color_sub_scheme',array(
			'description'	=> __('Select theme sub color from here.','holiday-lite'),
			'section' => 'colors',
			'settings' => 'color_sub_scheme'
		))
	);

	$wp_customize->add_setting('footer-color', array(
		'default' => '#000000',
		'sanitize_callback'	=> 'sanitize_hex_color',
	));
		
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'footer-color',array(
			'label' => __('Footer Background Color','holiday-lite'),
			'description'	=> __('Select background color for footer.','holiday-lite'),
			'section' => 'colors',
			'settings' => 'footer-color'
		))
	);
	
	/***************************************
	** Theme Setup Option Panel
	***************************************/
	
	// Theme Options Panel
	$wp_customize->add_panel( 'holiday_theme_options', 
		array(
			'title'            => __( 'Theme Setup', 'holiday-lite' ),
			'description'      => __( 'Theme Modifications like color scheme, theme texts and layout preferences can be done here', 'holiday-lite' ),
		) 
	);

	// Top Header Bar Section Inside Theme Options Panel
	$wp_customize->add_section( 'holiday_tp_header', 
		array(
			'title'         => __( 'Top Header Bar', 'holiday-lite' ),
			'priority'      => 1,
			'panel'         => 'holiday_theme_options',
			'description'      => __( 'Alter top header text and link from here or hide it.', 'holiday-lite' ),
		) 
	);
	
	$wp_customize->add_setting('holiday_tp_head_add',array(
		'sanitize_callback'	=> 'sanitize_text_field',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('holiday_tp_head_add',array(
		'type'	=> 'text',
		'label'	=> __('Add Address here.','holiday-lite'),
		'section'	=> 'holiday_tp_header'
	));

	$wp_customize->add_setting('holiday_tp_head_mail',array(
		'sanitize_callback'	=> 'sanitize_text_field',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('holiday_tp_head_mail',array(
		'type'	=> 'text',
		'label'	=> __('Add Email Address here.','holiday-lite'),
		'section'	=> 'holiday_tp_header'
	));

	$wp_customize->add_setting('holiday_tp_head_phn',array(
		'sanitize_callback'	=> 'sanitize_text_field',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('holiday_tp_head_phn',array(
		'type'	=> 'text',
		'label'	=> __('Add Phone Number here.','holiday-lite'),
		'section'	=> 'holiday_tp_header'
	));

	$wp_customize->add_setting('holiday_tp_head_fb',array(
		'sanitize_callback'	=> 'esc_url_raw',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('holiday_tp_head_fb',array(
		'type'	=> 'url',
		'label'	=> __('Add facebook url here.','holiday-lite'),
		'section'	=> 'holiday_tp_header'
	));

	$wp_customize->add_setting('holiday_tp_head_tw',array(
		'sanitize_callback'	=> 'esc_url_raw',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('holiday_tp_head_tw',array(
		'type'	=> 'url',
		'label'	=> __('Add twitter url here.','holiday-lite'),
		'section'	=> 'holiday_tp_header'
	));

	$wp_customize->add_setting('holiday_tp_head_yt',array(
		'sanitize_callback'	=> 'esc_url_raw',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('holiday_tp_head_yt',array(
		'type'	=> 'url',
		'label'	=> __('Add youtube url here.','holiday-lite'),
		'section'	=> 'holiday_tp_header'
	));

	$wp_customize->add_setting('holiday_tp_head_ins',array(
		'sanitize_callback'	=> 'esc_url_raw',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('holiday_tp_head_ins',array(
		'type'	=> 'url',
		'label'	=> __('Add instagram url here.','holiday-lite'),
		'section'	=> 'holiday_tp_header'
	));

	$wp_customize->add_setting('holiday_tp_head_lin',array(
		'sanitize_callback'	=> 'esc_url_raw',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('holiday_tp_head_lin',array(
		'type'	=> 'url',
		'label'	=> __('Add linkedin url here.','holiday-lite'),
		'section'	=> 'holiday_tp_header'
	));

	$wp_customize->add_setting('holiday_tp_head_pin',array(
		'sanitize_callback'	=> 'esc_url_raw',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('holiday_tp_head_pin',array(
		'type'	=> 'url',
		'label'	=> __('Add pinterest url here.','holiday-lite'),
		'section'	=> 'holiday_tp_header'
	));

	$wp_customize->add_setting('holiday_tp_head_btn',array(
		'sanitize_callback'	=> 'sanitize_text_field',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('holiday_tp_head_btn',array(
		'type'	=> 'url',
		'label'	=> __('Add Button text here.','holiday-lite'),
		'section'	=> 'holiday_tp_header'
	));

	$wp_customize->add_setting('holiday_tp_head_lnk',array(
		'sanitize_callback'	=> 'esc_url_raw',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('holiday_tp_head_lnk',array(
		'type'	=> 'url',
		'label'	=> __('Add Button url / link here.','holiday-lite'),
		'section'	=> 'holiday_tp_header'
	));

	$wp_customize->selective_refresh->add_partial('holiday_tp_head_btn', array(
		'selector' => '.booking-btn a'
	));

	$wp_customize->add_setting('holiday_hide_tphead',array(
		'default' => true,
		'sanitize_callback' => 'holiday_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 

	$wp_customize->add_control( 'holiday_hide_tphead', array(
		'settings' => 'holiday_hide_tphead',
		'label'     => __('Check to hide top header','holiday-lite'),
		'section'   => 'holiday_tp_header',
		'type'      => 'checkbox'
	));
	
	// Slider Section Inside Theme Options Panel
	$wp_customize->add_section( 'holiday_slider', 
		array(
			'title'         => __( 'Slider', 'holiday-lite' ),
			'priority'      => 2,
			'panel'         => 'holiday_theme_options',
			'description'      => __( 'Recommended image size (1400x800). Slider will work only when you select the static front page.', 'holiday-lite' ),
		) 
	);

	$wp_customize->add_setting( 'holiday_slide_sub_ttl', array(
			'default'	=> __('','holiday-lite'),
			'transport' => 'refresh',
			'sanitize_callback'	=> 'sanitize_text_field'
		)
	);
	
	$wp_customize->add_control('holiday_slide_sub_ttl',array(
		'label'	=> __('Add slider sub title here.','holiday-lite'),
		'section'	=> 'holiday_slider',
		'setting'	=> 'holiday_slide_sub_ttl',
		'type'	=> 'text'
	));

	$wp_customize->add_setting('slide1',array(
		'default' => '0',
		'transport' => 'refresh',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('slide1',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page for slide one:','holiday-lite'),
		'section'	=> 'holiday_slider'
	));
	
	$wp_customize->add_setting('slide2',array(
		'default' => '0',
		'transport' => 'refresh',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('slide2',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page for slide two:','holiday-lite'),
		'section'	=> 'holiday_slider'
	));
	
	$wp_customize->add_setting('slide3',array(
		'default' => '0',
		'transport' => 'refresh',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('slide3',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page for slide three:','holiday-lite'),
		'section'	=> 'holiday_slider'
	));
	
	$wp_customize->selective_refresh->add_partial('slide1', array(
        'selector' => '#holiday_slider'
    ));
	
	$wp_customize->add_setting('holiday_slider_btn',array(
		'default'	=> __('Read More','holiday-lite'),
		'transport' => 'refresh',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('holiday_slider_btn',array(
		'label'	=> __('Add slider read more button text.','holiday-lite'),
		'section'	=> 'holiday_slider',
		'setting'	=> 'holiday_slider_btn',
		'type'	=> 'text'
	));
	
	$wp_customize->add_setting('holiday_slider_hd',array(
		'default' => true,
		'sanitize_callback' => 'holiday_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 

	$wp_customize->add_control( 'holiday_slider_hd', array(
		'settings' => 'holiday_slider_hd',
		'section'   => 'holiday_slider',
		'label'     => __('Check this to hide slider.','holiday-lite'),
		'type'      => 'checkbox'
	));

	// First Section Inside Theme Options Panel
	$wp_customize->add_section( 'holiday_about', 
		array(
			'title'         => __( 'About Us Section', 'holiday-lite' ),
			'priority'      => 3,
			'panel'         => 'holiday_theme_options',
			'description'      => __( 'Select page to display about us section of theme. This will work only when you select the static front page', 'holiday-lite' ),
		)
	);
	
	$wp_customize->add_setting( 'holiday_about_sec', array(
			'default'	=> __('','holiday-lite'),
			'transport' => 'refresh',
			'sanitize_callback'	=> 'sanitize_text_field'
		)
	);
	
	$wp_customize->add_control('holiday_about_sec',array(
		'label'	=> __('Add sub title here.','holiday-lite'),
		'section'	=> 'holiday_about',
		'setting'	=> 'holiday_about_sec',
		'type'	=> 'text'
	));
	
	$wp_customize->add_setting('holiday_aboutpg',array(
		'default' => '0',
		'transport' => 'refresh',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('holiday_aboutpg',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page from here:','holiday-lite'),
		'section'	=> 'holiday_about'
	));
	
	$wp_customize->add_setting( 'holiday_about_more', array(
			'default'	=> __('Read More','holiday-lite'),
			'transport' => 'refresh',
			'sanitize_callback'	=> 'sanitize_text_field'
		)
	);
	
	$wp_customize->add_control('holiday_about_more',array(
		'label'	=> __('Add read more text here.','holiday-lite'),
		'section'	=> 'holiday_about',
		'setting'	=> 'holiday_about_more',
		'type'	=> 'text'
	));
	
	$wp_customize->add_setting('holiday_about_hd',array(
		'default' => true,
		'sanitize_callback' => 'holiday_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 

	$wp_customize->add_control( 'holiday_about_hd', array(
		'settings' => 'holiday_about_hd',
		'section'   => 'holiday_about',
		'label'     => __('Check this to hide section.','holiday-lite'),
		'type'      => 'checkbox'
	));
	
	// Second Section Inside Theme Options Panel
	$wp_customize->add_section( 'holiday_feat', 
		array(
			'title'         => __( 'Our Features Section', 'holiday-lite' ),
			'priority'      => 4,
			'panel'         => 'holiday_theme_options',
			'description'      => __( 'Select pages to display features section of theme. This will work only when you select the static front page', 'holiday-lite' ),
		)
	);
	
	$wp_customize->add_setting( 'holiday_feat_ttl', array(
			'default'	=> __('','holiday-lite'),
			'transport' => 'refresh',
			'sanitize_callback'	=> 'sanitize_text_field'
		)
	);
	
	$wp_customize->add_control('holiday_feat_ttl',array(
		'label'	=> __('Add section title here.','holiday-lite'),
		'section'	=> 'holiday_feat',
		'setting'	=> 'holiday_feat_ttl',
		'type'	=> 'text'
	));
	
	$wp_customize->add_setting('holiday_feat1',array(
		'default' => '0',
		'transport' => 'refresh',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('holiday_feat1',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page from here:','holiday-lite'),
		'section'	=> 'holiday_feat'
	));
	
	$wp_customize->add_setting('holiday_feat2',array(
		'default' => '0',
		'transport' => 'refresh',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('holiday_feat2',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page from here:','holiday-lite'),
		'section'	=> 'holiday_feat'
	));
	
	$wp_customize->add_setting('holiday_feat3',array(
		'default' => '0',
		'transport' => 'refresh',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('holiday_feat3',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page from here:','holiday-lite'),
		'section'	=> 'holiday_feat'
	));
	
	$wp_customize->add_setting('holiday_feat_hd',array(
		'default' => true,
		'sanitize_callback' => 'holiday_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'holiday_feat_hd', array(
		'settings' => 'holiday_feat_hd',
		'section'   => 'holiday_feat',
		'label'     => __('Check this to hide section.','holiday-lite'),
		'type'      => 'checkbox'
	));
	
}
add_action( 'customize_register', 'holiday_lite_customize_register' );	

function holiday_lite_css(){ ?>
<style>
	#header{
		background-color:<?php echo esc_attr(get_theme_mod('headerbg-color','#ffffff')); ?>;
	}
	a,
	.tm_client strong,
	.blog-post h3.entry-title,
	a.blog-more:hover,
	#commentform input#submit,
	input.search-submit,
	.nivo-controlNav a.active,
	.blog-date .date,
	a.read-more,
	p.site-description,
	.sitenav ul li.current_page_item a,
	.sitenav ul li a:hover,
	.sitenav ul li.current_page_item ul li a:hover,
	a.slide-button:hover,
	h4.section_sub_title,
	a.main-button:hover
	{
		color:<?php echo esc_attr(get_theme_mod('color_scheme','#f44c28')); ?>;
	}
	.booking-btn a:hover{
		color:<?php echo esc_attr(get_theme_mod('color_scheme','#f44c28')); ?> !important;
	}
	#holiday_slider .nivo-caption h4,
	a.slide-button:before,
	a.slide-button:after,
	a.main-button:before,
	a.main-button:after{
		border-color:<?php echo esc_attr(get_theme_mod('color_scheme','#f44c28')); ?>;
	}
	h3.widget-title,
	.nav-links .current,
	.nav-links a:hover,
	p.form-submit input[type="submit"],
	input[type="submit"].search-submit,
	.nivo-directionNav a,
	.top-header{
		background-color:<?php echo esc_attr(get_theme_mod('color_scheme','#f44c28')); ?>;
	}
	a:hover,
	#sidebar ul li a:hover,
	.postmeta a:hover,
	.top-header a:hover,
	a.main-button{
		color:<?php echo esc_attr(get_theme_mod('color_sub_scheme','#000000')); ?>;
	}
	a.main-button{
		border-color:<?php echo esc_attr(get_theme_mod('color_sub_scheme','#000000')); ?>;
	}
	.nivo-directionNav a:hover,
	.booking-btn a,
	.header-left,
	.header-left:before{
		background-color:<?php echo esc_attr(get_theme_mod('color_sub_scheme','#000000')); ?>;
	}
	.copyright-wrapper{
		background-color:<?php echo esc_attr(get_theme_mod('footer-color','#000000')); ?>;
	}
</style>        
<?php } add_action('wp_head','holiday_lite_css');

function holiday_lite_customize_preview_js() {
	wp_enqueue_script( 'holiday-lite-customize-preview', get_template_directory_uri() . '/js/customize-preview.js', array( 'customize-preview' ), '20141216', true );
}
add_action( 'customize_preview_init', 'holiday_lite_customize_preview_js' );